package com.yihu.hos.system.controller;

import com.yihu.hos.fegin.AppApiFegin;
import com.yihu.hos.system.model.AppApi;
import com.yihu.hos.web.framework.constant.ContextAttributes;
import com.yihu.hos.web.framework.model.Envelop;
import com.yihu.hos.web.framework.thread.LocalContext;
import com.yihu.hos.web.framework.util.controller.BaseController;
import net.sf.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.HashMap;
import java.util.Map;

/**
 * 应用管理
 */
@RequestMapping("/app/api")
@Controller
public class AppApiController extends BaseController {

    @Autowired
    private AppApiFegin appApiFegin;

    /**
     *  跳转到appApi列表页面
     *
     * @param model
     * @return
     */
    @RequestMapping("/initial")
    public String gotoList(Model model, String appId){
        model.addAttribute("appId",appId);
        model.addAttribute("contentPage", "system/app/api/appApi");
        return "partView";
    }

    @RequestMapping(value="/tree",produces = "application/json;charset=UTF-8")
    @ResponseBody
    public Object tree(String appId, String appName) {
        Map<String, Object> params = new HashMap<>();
        String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
        String tree = appApiFegin.tree(appId, appName, schemaName);
        return tree;
    }


    @RequestMapping(value="/list",produces = "application/json;charset=UTF-8")
    @ResponseBody
    public Object search(String parentId, String appId){
        try{
            Map<String, Object> params = new HashMap<>();
            Map<String, Object> filtersMap = new HashMap<>();
            filtersMap.put("parentId",parentId);
            filtersMap.put("appId",appId);
            String filters = JSONObject.fromObject(filtersMap).toString();
            params.put("filters",filters);
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            Envelop envelop = appApiFegin.getApiNoPage(filters, null, schemaName);
            return toJson(envelop);
        } catch (Exception e) {
            e.printStackTrace();
            Envelop result = new Envelop();
            result.setSuccessFlg(false);
            result.setErrorMsg("系统错误");
            return toJson(result);
        }
    }


    @RequestMapping("/gotoModify")
    public Object gotoModify(Model model, Integer id, String mode, String extParms,String appId,Integer parentId){
        try {
            Envelop envelop = new Envelop();

            Map<String, Object> params = new HashMap<>();
            params.put("id",id);
            params.put("mode",mode);
            params = putAll(extParms, params);

            if (!StringUtils.isEmpty(id)){ //如果id不为空,则通过微服务查询
                String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
                envelop = appApiFegin.getById(id,schemaName);
            }

            Object appApi;
            if(envelop.getObj()==null){
                AppApi tem = new AppApi();
                tem.setAppId(appId);
                tem.setParentId(parentId);
                appApi = tem;
            } else {
                appApi =envelop.getObj();
            }

            model.addAttribute("model",toJson(appApi));
            model.addAttribute("mode",mode);
            model.addAttribute("contentPage", "/system/app/api/dialog");
            if("add".equals(mode)){
                model.addAttribute("flag", "");
            }else {
                model.addAttribute("flag", "disabled");
            }
            model.addAttribute("staged", params.get("staged"));
            return "pageView";
        } catch (Exception e) {
            e.printStackTrace();
            Envelop result = new Envelop();
            result.setSuccessFlg(false);
            result.setErrorMsg("系统错误");
            return result;
        }
    }

}
