package com.yihu.hos.system.controller;

import com.yihu.hos.fegin.AppServiceFegin;
import com.yihu.hos.system.model.SystemServiceEndpoint;
import com.yihu.hos.system.service.AppManager;
import com.yihu.hos.web.framework.constant.ContextAttributes;
import com.yihu.hos.web.framework.model.Result;
import com.yihu.hos.web.framework.thread.LocalContext;
import com.yihu.hos.web.framework.util.controller.BaseController;
import net.sf.json.JSONObject;
import org.apache.commons.beanutils.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 应用管理
 */
@RequestMapping("/app")
@Controller
public class AppServiceController extends BaseController {

    @Resource(name = AppManager.BEAN_ID)
    private AppManager appManager;

    @Autowired
    private AppServiceFegin appServiceFegin;

    @RequestMapping("/initAppService")
    public String AppServiceInit(Model model,String appId) {
        model.addAttribute("appId", appId);
        model.addAttribute("contentPage", "system/app/appService");
        return "partView";
    }

    /**
     * 应用管理
     *   -服务管理页面
     *
     * @param request
     * @return
     */
    @RequestMapping("/getAppServiceList")
    @ResponseBody
    public Result getAppServiceList(HttpServletRequest request, String name, String valid, String appId) {
        try {
            Map<String, Object> params = new HashMap<>();
            params.put("name", name);
            params.put("valid", valid);
            params.put("appId", appId);

            String pageStr = StringUtils.isEmpty(request.getParameter("page")) ? "1" : request.getParameter("page");
            Integer page = Integer.valueOf(pageStr);
            String rowsStr = StringUtils.isEmpty(request.getParameter("rows")) ? "10" : request.getParameter("rows");
            Integer rows = Integer.valueOf(rowsStr);

            params.put("page", page);
            params.put("rows", rows);

            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            params.put("schemaName",schemaName);

            //todo 改成从微服务获取列表
            Result result = appManager.getAppServiceList(params);
            return result;
        } catch (Exception ex) {
            ex.printStackTrace();
            return Result.error(ex.getMessage());
        }

    }

    /**
     * 服务修改页面
     * @param model
     * @param id
     * @return
     */
    @RequestMapping("/editorAppService")
    public String editorAppServicePage(Model model, String id,String appId) {
        try {
            SystemServiceEndpoint appService = null;
            if (id != null && id.length() > 0) {
                String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
                appService = appServiceFegin.getAppService(id,schemaName);
            }  else {
                appService = new SystemServiceEndpoint();
            }
            model.addAttribute("model", appService);
            model.addAttribute("appId", appId);
            model.addAttribute("contentPage", "/system/app/editorAppService");
        } catch (Exception e) {
            e.printStackTrace();
        }
        return "pageView";
    }

    /**
     * 服务详情页
     * @param model
     * @param id
     * @returnServiceS
     */
    @RequestMapping("/appServiceDetail")
    public String appServiceDetail(Model model, String id) {
        try {
            SystemServiceEndpoint app = null;
            if (id != null && id.length() > 0) {
                String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
                app = appServiceFegin.getAppService(id,schemaName);
            }  else {
                app = new SystemServiceEndpoint();
            }
            model.addAttribute("model", app);
            model.addAttribute("contentPage", "/system/app/appServiceDetail");
        } catch (Exception e) {
            e.printStackTrace();
        }
        return "pageView";
    }


    /**
     * 新增服务信息
     * @param request
     * @return
     */
    @RequestMapping("addAppService")
    @ResponseBody
    public Result addAppService(HttpServletRequest request) {
        try {
            SystemServiceEndpoint obj = new SystemServiceEndpoint();
            BeanUtils.populate(obj, request.getParameterMap());
            JSONObject jsonObj = JSONObject.fromObject(obj);
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            SystemServiceEndpoint service = appServiceFegin.create(jsonObj.toString(), schemaName);
            if(service!=null){
                return Result.success("保存成功");
            }else{
                return Result.error("保存失败，应用Code已存在");
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            return Result.error(ex.getMessage());
        }
    }

    /**
     * 删除服务信息
     * @param request
     * @return
     */
    @RequestMapping("/deleteAppService")
    @ResponseBody
    public Result deleteAppService(HttpServletRequest request) {

        try {
            String id = request.getParameter("id");
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            appServiceFegin.delete(id, schemaName);
            return Result.success("删除成功！");
        } catch (Exception e) {
            e.printStackTrace();
            return Result.error("删除失败！");
        }
    }

    /**
     * 修改服务信息
     */
    @RequestMapping("updateAppService")
    @ResponseBody
    public Result updateAppService(HttpServletRequest request) {
        try {
            SystemServiceEndpoint obj = new SystemServiceEndpoint();
            BeanUtils.populate(obj, request.getParameterMap());

            JSONObject jsonObj = JSONObject.fromObject(obj);
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);

            SystemServiceEndpoint app = appServiceFegin.update(jsonObj.toString(),schemaName);
            if(app!=null){
                return Result.success("更新成功");
            }else{
                return Result.error("更新失败，应用Code已存在");
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            return Result.error(ex.getMessage());
        }
    }

}
